searchData={"items":[{"type":"module","title":"Mock","doc":"Mock modules for testing purposes. Usually inside a unit test.\n\nPlease see the README file on github for a tutorial","ref":"Mock.html"},{"type":"module","title":"Example - Mock","doc":"defmodule MyTest do\n      use ExUnit.Case\n      import Mock\n\n      test \"get\" do\n        with_mock HTTPotion,\n            [get: fn(\"http://example.com\", _headers) ->\n                    HTTPotion.Response.new(status_code: 200,\n                        body: \"hello\") end] do\n          # Code which calls HTTPotion.get\n          # Check that the call was made as we expected\n          assert called HTTPotion.get(\"http://example.com\", :_)\n        end\n      end\n    end","ref":"Mock.html#module-example"},{"type":"macro","title":"Mock.assert_called/1","doc":"Use inside a `with_mock` block to determine whether\na mocked function was called as expected. If the assertion fails,\nthe calls that were received are displayed in the assertion message.\n\nPass `:_` as a function argument for wildcard matches.","ref":"Mock.html#assert_called/1"},{"type":"macro","title":"Example - Mock.assert_called/1","doc":"assert_called HTTPotion.get(\"http://example.com\")\n\n    # Matches any invocation\n    assert_called HTTPotion.get(:_)","ref":"Mock.html#assert_called/1-example"},{"type":"macro","title":"Mock.assert_called_at_least/2","doc":"Use inside a `with_mock` block to determine whether a mocked function was called\n  as expected at least x times. If the assertion fails, the number of calls that\n  were received is displayed in the assertion message.\n\n  Pass `:_` as a function argument for wildcard matches.","ref":"Mock.html#assert_called_at_least/2"},{"type":"macro","title":"Example - Mock.assert_called_at_least/2","doc":"assert_called_at_least HTTPotion.get(\"http://example.com\"), 2\n\n      # Matches any invocation\n      assert_called_at_leaset HTTPotion.get(:_), 2","ref":"Mock.html#assert_called_at_least/2-example"},{"type":"macro","title":"Mock.assert_called_exactly/2","doc":"Use inside a `with_mock` block to determine whether a mocked function was called\n  as expected exactly x times. If the assertion fails, the number of calls that\n  were received is displayed in the assertion message.\n\n  Pass `:_` as a function argument for wildcard matches.","ref":"Mock.html#assert_called_exactly/2"},{"type":"macro","title":"Example - Mock.assert_called_exactly/2","doc":"assert_called_exactly HTTPotion.get(\"http://example.com\"), 2\n\n      # Matches any invocation\n      assert_called_exactly HTTPotion.get(:_), 2","ref":"Mock.html#assert_called_exactly/2-example"},{"type":"macro","title":"Mock.assert_not_called/1","doc":"Use inside a `with_mock` block to check if\na mocked function was NOT called. If the assertion fails,\nthe number of calls is displayed in the assertion message.\n\nPass `:_` as a function argument for wildcard matches.","ref":"Mock.html#assert_not_called/1"},{"type":"macro","title":"Example - Mock.assert_not_called/1","doc":"assert_not_called HTTPotion.get(\"http://example.com\")\n\n    # Matches any invocation\n    assert_not_called HTTPotion.get(:_)","ref":"Mock.html#assert_not_called/1-example"},{"type":"macro","title":"Mock.call_history/1","doc":"Helper function to get the history of mock functions executed.","ref":"Mock.html#call_history/1"},{"type":"macro","title":"Example - Mock.call_history/1","doc":"iex> assert call_history(HTTPotion) == [\n        {pid, {HTTPotion, :get, [\"http://example.com\"]}, some_return_value}\n      ]","ref":"Mock.html#call_history/1-example"},{"type":"macro","title":"Mock.called/1","doc":"Use inside a `with_mock` block to determine whether\na mocked function was called as expected.\n\nPass `:_` as a function argument for wildcard matches.","ref":"Mock.html#called/1"},{"type":"macro","title":"Example - Mock.called/1","doc":"assert called HTTPotion.get(\"http://example.com\")\n\n    # Matches any invocation\n    assert called HTTPotion.get(:_)","ref":"Mock.html#called/1-example"},{"type":"function","title":"Mock.in_series/2","doc":"","ref":"Mock.html#in_series/2"},{"type":"macro","title":"Mock.mock_modules/1","doc":"","ref":"Mock.html#mock_modules/1"},{"type":"macro","title":"Mock.passthrough/1","doc":"Call original function inside mock anonymous function.\nAllows overriding only a certain behavior of a function.\nCompatible with passthrough option.","ref":"Mock.html#passthrough/1"},{"type":"macro","title":"Example - Mock.passthrough/1","doc":"with_mock String, [:passthrough], [reverse: fn(str) ->\n         passthrough([str]) <> \"!\" end] do\n       assert String.reverse(\"xyz\") == \"zyx!\"\n    end","ref":"Mock.html#passthrough/1-example"},{"type":"macro","title":"Mock.setup_with_mocks/2","doc":"Mocks up multiple modules prior to the execution of each test in a case and\nexecute the callback specified.\n\nFor full description of mocking, see `with_mocks`.\n\nFor a full description of ExUnit setup, see\nhttps://hexdocs.pm/ex_unit/ExUnit.Callbacks.html","ref":"Mock.html#setup_with_mocks/2"},{"type":"macro","title":"Example - Mock.setup_with_mocks/2","doc":"setup_with_mocks([\n      {Map, [], [get: fn(%{}, \"http://example.com\") -> \"  \" end]}\n    ]) do\n      foo = \"bar\"\n      {:ok, foo: foo}\n    end\n\n    test \"setup_all_with_mocks base case\" do\n      assert Map.get(%{}, \"http://example.com\") == \"  \"\n    end","ref":"Mock.html#setup_with_mocks/2-example"},{"type":"macro","title":"Mock.setup_with_mocks/3","doc":"Mocks up multiple modules prior to the execution of each test in a case and\nexecute the callback specified with a context specified\n\nSee `setup_with_mocks` for more details","ref":"Mock.html#setup_with_mocks/3"},{"type":"macro","title":"Example - Mock.setup_with_mocks/3","doc":"setup_with_mocks([\n      {Map, [], [get: fn(%{}, \"http://example.com\") -> \"  \" end]}\n    ], context) do\n      {:ok, test_string: Atom.to_string(context.test)}\n    end\n\n    test \"setup_all_with_mocks with context\", %{test_string: test_string} do\n      assert Map.get(%{}, \"http://example.com\") == \"  \"\n      assert test_string == \"test setup_all_with_mocks with context\"\n    end","ref":"Mock.html#setup_with_mocks/3-example"},{"type":"macro","title":"Mock.test_with_mock/5","doc":"Shortcut to avoid multiple blocks when a test requires a single\nmock.\n\nFor full description see `with_mock`.","ref":"Mock.html#test_with_mock/5"},{"type":"macro","title":"Example - Mock.test_with_mock/5","doc":"test_with_mock \"test_name\", HTTPotion,\n      [get: fn(_url) -> \"  \" end] do\n      HTTPotion.get(\"http://example.com\")\n      assert called HTTPotion.get(\"http://example.com\")\n    end","ref":"Mock.html#test_with_mock/5-example"},{"type":"macro","title":"Mock.test_with_mock/6","doc":"Shortcut to avoid multiple blocks when a test requires a single\nmock. Accepts a context argument enabling information to be shared\nbetween callbacks and the test.\n\nFor full description see `with_mock`.","ref":"Mock.html#test_with_mock/6"},{"type":"macro","title":"Example - Mock.test_with_mock/6","doc":"setup do\n      doc = \"  \"\n      {:ok, doc: doc}\n    end\n\n    test_with_mock \"test_with_mock with context\", %{doc: doc}, HTTPotion, [],\n      [get: fn(_url) -> doc end] do\n\n      HTTPotion.get(\"http://example.com\")\n      assert called HTTPotion.get(\"http://example.com\")\n    end","ref":"Mock.html#test_with_mock/6-example"},{"type":"macro","title":"Mock.test_with_mocks/3","doc":"Shortcut to avoid multiple blocks when a test requires multiple\nmocks.\n\nFor full description see `test_with_mocks`.","ref":"Mock.html#test_with_mocks/3"},{"type":"macro","title":"Example - Mock.test_with_mocks/3","doc":"test_with_mocks \"test_name\", [{HTTPotion,[],\n      [get: fn(_url) -> \"  \" end]}] do\n      HTTPotion.get(\"http://example.com\")\n      assert called HTTPotion.get(\"http://example.com\")\n    end","ref":"Mock.html#test_with_mocks/3-example"},{"type":"macro","title":"Mock.test_with_mocks/4","doc":"Shortcut to avoid multiple blocks when a test requires multiple\nmocks. Accepts a context argument enabling information to be shared\nbetween callbacks and the test.\n\nFor full description see `test_with_mocks`.","ref":"Mock.html#test_with_mocks/4"},{"type":"macro","title":"Example - Mock.test_with_mocks/4","doc":"test_with_mocks \"test_name\", %{foo: foo} [{HTTPotion,[],\n      [get: fn(_url) -> \"  \" end]}] do\n      HTTPotion.get(\"http://example.com\")\n      assert called HTTPotion.get(\"http://example.com\")\n      assert foo == \"bar\"\n    end","ref":"Mock.html#test_with_mocks/4-example"},{"type":"macro","title":"Mock.with_mock/4","doc":"Mock up `mock_module` with functions specified as a keyword\nlist of function_name:implementation `mocks` for the duration\nof `test`.\n\n`opts` List of optional arguments passed to meck. `:passthrough` will\n passthrough arguments to the original module.","ref":"Mock.html#with_mock/4"},{"type":"macro","title":"Example - Mock.with_mock/4","doc":"with_mock HTTPotion, [get: fn(\"http://example.com\") ->\n         \"  \" end] do\n       # Tests that make the expected call\n       assert called HTTPotion.get(\"http://example.com\")\n    end","ref":"Mock.html#with_mock/4-example"},{"type":"macro","title":"Mock.with_mocks/2","doc":"Mock up multiple modules for the duration of `test`.","ref":"Mock.html#with_mocks/2"},{"type":"macro","title":"Example - Mock.with_mocks/2","doc":"with_mocks([{HTTPotion, opts, [get: fn(\"http://example.com\") -> \"  \" end]}]) do\n      # Tests that make the expected call\n      assert called HTTPotion.get(\"http://example.com\")\n    end","ref":"Mock.html#with_mocks/2-example"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}